summaryrefslogtreecommitdiffhomepage
path: root/dev/lib/io
diff options
context:
space:
mode:
authorAmlal El Mahrouss <amlal@nekernel.org>2025-08-27 12:28:55 +0200
committerAmlal El Mahrouss <amlal@nekernel.org>2025-08-27 12:31:41 +0200
commitb4f35dbe44e07b597c3e7bb6d7562757069a7cb4 (patch)
tree88af99a2cca9c514536b4b61785fa67b3543429c /dev/lib/io
parentfbda49eea45ce08b9a72744c04761e1556ebd2fa (diff)
feat: moved SOCL into OCL, without SNU's baggage.v1.0.41
Signed-off-by: Amlal El Mahrouss <amlal@nekernel.org>
Diffstat (limited to 'dev/lib/io')
-rw-r--r--dev/lib/io/print.hpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/dev/lib/io/print.hpp b/dev/lib/io/print.hpp
index 840b373..4b32ddb 100644
--- a/dev/lib/io/print.hpp
+++ b/dev/lib/io/print.hpp
@@ -1,17 +1,17 @@
/*
* File: print.hpp
* Purpose: SNU Print library
* Author: Amlal El Mahrouss. (founder@snu.systems)
* Copyright 2025, SNU Systems Corp.
*/
-#ifndef _SNU_PRINT_HPP
-#define _SNU_PRINT_HPP
+#ifndef _OCL_PRINT_HPP
+#define _OCL_PRINT_HPP
#include <iostream>
#include <ostream>
-namespace snu::io
+namespace ocl::io
{
template <typename T, typename... Args>
inline void print(T fmt, Args... other) noexcept
@@ -36,6 +36,6 @@ namespace snu::io
{
print(fmt...);
}
-} // namespace snu::io
+} // namespace ocl::io
-#endif // ifndef _SNU_PRINT_HPP
+#endif // ifndef _OCL_PRINT_HPP
@@ -1,17 +1,17 @@
/*
* File: print.hpp
- * Purpose: SNU Print library
- * Author: Amlal El Mahrouss. (founder@snu.systems)
- * Copyright 2025, SNU Systems Corp.
+ * Purpose: OCL Print library
+ * Author: Amlal El Mahrouss. (amlal@nekernel.org)
+ * Copyright 2025
*/